@@ -18,14 +18,14 @@
 #'		\code{fx,fr} non-normalized probability density for line transects and point counts respectively
 #' 
 #' @aliases detfct adjfct.cos adjfct.herm hermite.poly adjfct.poly keyfct.hn keyfct.hz 
-#'  keyfct.gamma apex.gamma scalevalue g0 fx fr 
+#'  keyfct.gamma apex.gamma scalevalue g0 fx fr distpdf
 #' @usage 	detfct(distance, ddfobj, select=NULL, index=NULL, width=NULL, standardize = TRUE, stdint=FALSE)
 #' 
-#'	adjfct.cos(distance, scaling = 1, adj.order, adj.parm = NULL)
+#'	adjfct.cos(distance, scaling = 1, adj.order, adj.parm = NULL, adj.exp=FALSE)
 #' 
-#'	adjfct.poly(distance, scaling = 1, adj.order, adj.parm = NULL)
+#'	adjfct.poly(distance, scaling = 1, adj.order, adj.parm = NULL, adj.exp=FALSE)
 #' 
-#'	adjfct.herm(distance, scaling = 1, adj.order, adj.parm = NULL)
+#'	adjfct.herm(distance, scaling = 1, adj.order, adj.parm = NULL, adj.exp=FALSE)
 #' 
 #'	scalevalue(key.scale, z)
 #' 
@@ -41,6 +41,8 @@
 #' 
 #'	fr(distance,ddfobj,select=NULL,index=NULL,width=NULL,standardize=TRUE,stdint=FALSE)
 #' 
+#'	distpdf(distance,ddfobj,select=NULL,index=NULL,width=NULL,standardize=TRUE,stdint=FALSE,point=FALSE)
+#' 
 #' @param distance  vector of distances 
 #' @param ddfobj distance sampling object (see \code{\link{create.ddfobj}}) 
 #' @param z design matrix for scale function
@@ -54,24 +56,34 @@
 #' @param standardize logical used to decide whether to divide through by the function evaluated at 0 
 #' @param scaling the scaling for the adjustment terms 
 #' @param stdint logical used to decide whether integral is standardized
+#' @param point if TRUE, point counts; otherwise line transects
+#' @param adj.exp if TRUE uses exp(adj) for adjustment to keep f(x)>0
 #' @return 
 #'	For \code{detfct}, the value is a vector of detection probabilities for the input set of x and z.
 #'	For \code{keyfct.hn, keyfct.hz}, vector of detection probability for that key function at x.
 #'	For \code{adjfct.cos, adjfct.poly, adjfct.herm}, vector of the value of the adjustment term at x.
 #'	For \code{scalevalue}, the value is a vector of the computed scales for the design matrix z. 
 #'	For \code{apex.gamma}, the value is the distance at which the gamma peaks
-#' @author Jeff Laake David Miller
+#' @author Jeff Laake, David Miller
 #' @seealso  \code{\link{mcds}},  \code{\link{cds}}
 #' @references 	Marques and Buckland 2004
 #'	Laake and Borchers 2004. in Buckland et al 2004.
 #'	Becker, E. F. and P. X. Quang. 2009. A gamma-shaped detection function for line transect surveys with mark-recapture and covariate data. Journal of Agricultural Biological and Environmental Statistics 14:207-223.
+distpdf <- function(distance,ddfobj,select=NULL,index=NULL,width=NULL,standardize=TRUE,stdint=FALSE,point=FALSE)
+{
+	if(!point)
+		return(fx(distance=distance,ddfobj=ddfobj,select=select,index=index,width=width,standardize=standardize,stdint=stdint))
+	else
+		return(fr(distance=distance,ddfobj=ddfobj,select=select,index=index,width=width,standardize=standardize,stdint=stdint))	
+}
 fx <- function(distance,ddfobj,select=NULL,index=NULL,width=NULL,standardize=TRUE,stdint=FALSE)
 	return(detfct(distance,ddfobj,select,index,width,standardize,stdint)/width)
+
 fr <- function(distance,ddfobj,select=NULL,index=NULL,width=NULL,standardize=TRUE,stdint=FALSE)
 	return(detfct(distance,ddfobj,select,index,width,standardize,stdint)*2*distance/width^2)
-detfct <-
-function(distance,ddfobj,select=NULL,index=NULL,width=NULL,standardize=TRUE,stdint=FALSE)
-{
+
+detfct <- function(distance,ddfobj,select=NULL,index=NULL,width=NULL,
+		standardize=TRUE,stdint=FALSE){
 #
 # detfct - calls key and adjustment terms to create the detection function
 #
@@ -89,99 +101,106 @@ function(distance,ddfobj,select=NULL,index=NULL,width=NULL,standardize=TRUE,stdi
 #
 # Uses : getpar, scalevalue, keyfct.hn, keyfct.hz, adjfct.poly, adjfct.herm, adjfct.cos
 #
-  if(is.null(select))
-  {
-	  if(is.null(index))
-	  {
-		  scale.dm=ddfobj$scale$dm
-		  shape.dm=ddfobj$shape$dm
-	  }
-	  else
-	  {
-		  scale.dm=ddfobj$scale$dm[index,,drop=FALSE]
-		  shape.dm=ddfobj$shape$dm[index,,drop=FALSE]
-	  }
-  } else
-  {
-	  if(is.null(index))
-	  {
-		  scale.dm=ddfobj$scale$dm[select,,drop=FALSE]
-		  shape.dm=ddfobj$shape$dm[select,,drop=FALSE]
-	  }
-	  else
-	  {
-		  scale.dm=ddfobj$scale$dm[select,,drop=FALSE][index,,drop=FALSE]
-		  shape.dm=ddfobj$shape$dm[select,,drop=FALSE][index,,drop=FALSE]
-	  }
-  }	  
-  key=ddfobj$type
-# calculate the key scale 
-  if(stdint)
-  {
-	  if(is.null(index))
-	    key.scale=rep(1,nrow(scale.dm))
-      else
-		key.scale=1  
-  }else
-  {
-	if(!is.null(ddfobj$scale))
-	  key.scale <- scalevalue(ddfobj$scale$parameters,scale.dm)
-  }
-# calculate the key shape
-  if(!is.null(ddfobj$shape)) 
-	  key.shape <- scalevalue(ddfobj$shape$parameters,shape.dm)
-  if(key=="gamma")
-  {	  
-	  key.shape=key.shape+1
-	  key.shape[key.shape==1]=key.shape[key.shape==1]+0.000001
-  } 
-# 19-Jan-06 jll; added proper standardize code to get std integral.
-#  I left standardize code below in case it is needed for adjustment fcts
 #
-# Decide on keyfct.* and run.
-  if(key == "hn"){
-	key.vals <- keyfct.hn(distance, key.scale)
-  }else if(key == "hr"){
-	key.vals <- keyfct.hz(distance, key.scale, key.shape)
-  }else if(key == "unif"){
-	key.vals <- rep(1/width,length(distance))
-  }else if(key == "gamma"){
-	key.vals <- keyfct.gamma(distance, key.scale, key.shape)
+# Set of observations for computation of detection function can
+# be specified with logical (select) and numeric (index) values.
+# Either or both can be specified although the latter is unlikely.
+  if(is.null(select)){
+    # use all
+    if(is.null(index)){
+      scale.dm <- ddfobj$scale$dm
+      shape.dm <- ddfobj$shape$dm
+    }else{
+      # use only those with specific indices
+      scale.dm <- ddfobj$scale$dm[index,,drop=FALSE]
+      shape.dm <- ddfobj$shape$dm[index,,drop=FALSE]
+    }
+  }else{
+    # Use those with select=TRUE
+    if(is.null(index)){
+      scale.dm <- ddfobj$scale$dm[select,,drop=FALSE]
+      shape.dm <- ddfobj$shape$dm[select,,drop=FALSE]
+    }else{
+      # use the numeric index within those with select=TRUE
+      scale.dm <- ddfobj$scale$dm[select,,drop=FALSE][index,,drop=FALSE]
+      shape.dm <- ddfobj$shape$dm[select,,drop=FALSE][index,,drop=FALSE]
+    }
+  } 
+
+  # Key function 
+  key <- ddfobj$type
+
+  # calculate the key scale 
+  if(stdint){
+    if(is.null(index)){
+      key.scale <- rep(1,nrow(scale.dm))
+    }else{
+      key.scale <- 1
+    }
+  }else{
+    if(!is.null(ddfobj$scale)){
+      key.scale <- scalevalue(ddfobj$scale$parameters,scale.dm)
+    }
   }
 
+  # calculate the key shape
+  if(!is.null(ddfobj$shape)){
+    key.shape <- scalevalue(ddfobj$shape$parameters,shape.dm)
+  }
+
+  if(key=="gamma"){	  
+    key.shape=key.shape+1
+    key.shape[key.shape==1]=key.shape[key.shape==1]+0.000001
+  }
+ 
+  # 19-Jan-06 jll; added proper standardize code to get std integral.
+  #  I left standardize code below in case it is needed for adjustment fcts
+  #
+  # Decide on keyfct.* and run.
+  if(key == "hn"){
+    key.vals <- keyfct.hn(distance, key.scale)
+  }else if(key == "hr"){
+    key.vals <- keyfct.hz(distance, key.scale, key.shape)
+  }else if(key == "unif"){
+    key.vals <- rep(1/width,length(distance))
+  }else if(key == "gamma"){
+    key.vals <- keyfct.gamma(distance, key.scale, key.shape)
+  }
+
+  # Adjustment functions
   # If we are using adjustment terms.
   if(!is.null(ddfobj$adjustment)){
-    adj.series=ddfobj$adjustment$series
-	 adj.scale=ddfobj$adjustment$scale
-	 adj.order=ddfobj$adjustment$order
-	 adj.parm=ddfobj$adjustment$parameters
-		
+    adj.series <- ddfobj$adjustment$series
+    adj.scale <- ddfobj$adjustment$scale
+    adj.order <- ddfobj$adjustment$order
+    adj.parm <- ddfobj$adjustment$parameters
+    adj.exp <- ddfobj$adjustment$exp
+    
     # Find out if we are scaling by width or by key scale
-    if(adj.scale == "width")
+    if(adj.scale == "width"){
       scaling <- width
-    else
+    }else{
       scaling <- key.scale
+    }
 
     ## Decide on adjustment term and run.
     # If we have simple polynomials
     if(adj.series == "poly"){
-      adj.vals <- adjfct.poly(distance,scaling,adj.order,adj.parm)
-
+      adj.vals <- adjfct.poly(distance,scaling,adj.order,adj.parm,adj.exp)
     # Hermite polynomials
     }else if(adj.series == "herm"){
-      adj.vals <- adjfct.herm(distance,scaling,adj.order,adj.parm)
-
+      adj.vals <- adjfct.herm(distance,scaling,adj.order,adj.parm,adj.exp)
     # Cosine series
     }else if(adj.series == "cos"){
-      adj.vals <- adjfct.cos(distance,scaling,adj.order,adj.parm)
+      adj.vals <- adjfct.cos(distance,scaling,adj.order,adj.parm,adj.exp)
     }
-
-# If we have adjustment terms then we need to standardize the detection
-# function. So find the values for the key and adjustment terms at 0   
-
-# dlm 25-Aug-05  This causes a division by zero error in the optimization
-#		 so lets only do it when we need to, it cancels in the
-#		 likelihood anyway.
+		
+    # If we have adjustment terms then we need to standardize the detection
+    # function. So find the values for the key and adjustment terms at 0   
+    		
+    # dlm 25-Aug-05  This causes a division by zero error in the optimization
+    #		 so lets only do it when we need to, it cancels in the
+    #		 likelihood anyway.
     if(standardize == TRUE){
       if(key == "hn"){
         key.val.0 <- keyfct.hn(rep(0,length(distance)), key.scale)
@@ -190,26 +209,44 @@ function(distance,ddfobj,select=NULL,index=NULL,width=NULL,standardize=TRUE,stdi
       }else if(key == "gamma"){
         key.val.0 <- keyfct.gamma(rep(0,length(distance)), key.scale, key.shape)
       }else if(key == "unif"){
-        key.val.0 <- rep(1,length(distance))
+        key.val.0 <- rep(1/width,length(distance))
       }
-
+	
       if(adj.series == "poly"){
-        adj.val.0 <- adjfct.poly(rep(0,length(distance)),scaling,adj.order,adj.parm)
+        adj.val.0 <- adjfct.poly(rep(0,length(distance)),scaling,
+                                 adj.order,adj.parm,adj.exp)
       }else if(adj.series == "herm"){
-        adj.val.0 <- adjfct.herm(rep(0,length(distance)),scaling,adj.order,adj.parm)
+        adj.val.0 <- adjfct.herm(rep(0,length(distance)),scaling,
+                                 adj.order,adj.parm,adj.exp)
       }else if(adj.series == "cos"){
-        adj.val.0 <- adjfct.cos(rep(0,length(distance)),scaling,adj.order,adj.parm)
+        adj.val.0 <- adjfct.cos(rep(0,length(distance)),scaling,
+                                adj.order,adj.parm,adj.exp)
       }
 
-# Now return the standardized value of the detection function
+      # Now return the standardized value of the detection function
       return((key.vals*(1+adj.vals))/(key.val.0*(1+adj.val.0)))
 
-    }else
+    }else{
       return(key.vals*(1+adj.vals))
-
+    }
   }else{
-# If we have no adjustment terms then just return the key value.
-    return(key.vals)
+    # jll 26 June 2012 -- added standardization for key to handle unif key only
+    # and any other non-standard keys that could be added
+    # If we have no adjustment terms then just return the key value.
+    if(standardize == TRUE){
+      if(key == "hn"){
+        key.val.0 <- keyfct.hn(rep(0,length(distance)), key.scale)
+      }else if(key == "hr"){
+        key.val.0 <- keyfct.hz(rep(0,length(distance)), key.scale, key.shape)
+      }else if(key == "gamma"){
+        key.val.0 <- keyfct.gamma(rep(0,length(distance)), key.scale, key.shape)
+      }else if(key == "unif"){
+        key.val.0 <- rep(1/width,length(distance))
+      }
+      # Now return the standardized value of the detection function
+      return(key.vals/key.val.0)
+    }else{
+      return(key.vals)
+    }
   }
 }
-
