@@ -54,72 +54,68 @@
 #' @seealso \code{\link{ddf}}, \code{\link{summary.io.fi}},
 #'   \code{\link{plot.io.fi}}
 #' @keywords utility
-predict.io.fi <-
-function(object,newdata=NULL,compute=FALSE, int.range=NULL, integrate=FALSE,...)
-#
-# predict.io.fi - computes fitted values for p 
-#                 if model object already contains fitted values it uses those,
-#                 otherwise it calculates them
-# 
-# arguments:
-#
-# object     - io.fi model object
-# newdata    - data for which predictions made - only used to change value of distance to 0
-# compute    - if TRUE re-compute fitted values even if they are in model
-# int.range  - integration range for variable range analysis
-# integrate  - if TRUE compute integral of p(x) otherwise just p(x)
-#
-# return value
-#  list with 1 element - vector of fitted detection probabilities 
-# 
-# Functions Used: pdot.dsr.integrate.logistic, is.linear.logistic, predict.glm (could also use predict.gam eventually) 
-#   
-{
-	model=object
-	width=model$meta.data$width
-	point=model$meta.data$point
-	if(is.null(newdata))
-      newdata=model$mr$data
-   newdata$offsetvalue=0
-   GAM=FALSE
-   if("gam" %in% class(model$mr)) GAM=TRUE
-   if(!integrate)
-   {
-       fitted=predict(model$mr,newdata,type="response")
-       p1<-fitted[model$mr$data$observer==1]
-       p2<-fitted[model$mr$data$observer==2]
-       fitted=p1+p2-p1*p2
-       if(is.null(newdata))
-          names(fitted)=model$mr$data$object[model$mr$data$observer==1]
-       else
-          names(fitted)=newdata$object[newdata$observer==1]
-          return(list(fitted=fitted,p1=p1,p2=p2))
-   } else
-   {
-       left=model$meta.data$left
-       formula=paste("~",as.character(model$mr$formula)[3],collapse="")
-       if ("gam" %in% class(model$mr))
-         integral.numeric<-TRUE
-       else
-         integral.numeric <- is.linear.logistic(newdata,formula,length(coef(model$mr)),width)
-       models<- list(g0model=formula,scalemodel=NULL,fullscalemodel=NULL)
-#
-#      Name int.range is misleading because it is only a right-hand point different
-#      from width;  this needs to be expanded to an interval in the future
-#
-       if(is.null(int.range))
-          pdot.list <- pdot.dsr.integrate.logistic(width,width, model$mr$coef, newdata,integral.numeric, FALSE, models,GAM, point=point)
-       else
-          pdot.list <- pdot.dsr.integrate.logistic(int.range,width, model$mr$coef, newdata,integral.numeric, FALSE, models,GAM, point=point)
-       if(left !=0) pdot.list$pdot <- pdot.list$pdot -
-                       pdot.dsr.integrate.logistic(left, width, model$mr$coef, newdata,integral.numeric, FALSE, models,GAM, point=point)$pdot
-       fitted <- pdot.list$pdot
-       if(is.null(newdata))
-          names(fitted)=model$mr$data$object[model$mr$data$observer==1]
-       else
-          names(fitted)=newdata$object[newdata$observer==1]
-       return(list(fitted=fitted))
-   }
+predict.io.fi <- function(object,newdata=NULL,compute=FALSE, int.range=NULL, 
+                          integrate=FALSE,...){
+# Functions Used: pdot.dsr.integrate.logistic, is.linear.logistic, 
+#                 predict.glm (could also use predict.gam eventually) 
+  model <- object
+  width <- model$meta.data$width
+  point <- model$meta.data$point
+  if(is.null(newdata)){
+    newdata <- model$mr$data
+  }
+  newdata$offsetvalue <- 0
+  GAM <- FALSE
+  if("gam" %in% class(model$mr)){
+    GAM <- TRUE
+  }
+  if(!integrate){
+    fitted <- predict(model$mr,newdata,type="response")
+    p1 <- fitted[model$mr$data$observer==1]
+    p2 <- fitted[model$mr$data$observer==2]
+    fitted <- p1+p2-p1*p2
+    if(is.null(newdata)){
+       names(fitted) <- model$mr$data$object[model$mr$data$observer==1]
+    }else{
+       names(fitted)=newdata$object[newdata$observer==1]
+    }
+    return(list(fitted=fitted,p1=p1,p2=p2))
+  }else{
+    left <- model$meta.data$left
+    formula <- paste("~",as.character(model$mr$formula)[3],collapse="")
+    if("gam" %in% class(model$mr)){
+      integral.numeric <- TRUE
+    }else{
+      integral.numeric <- is.linear.logistic(newdata,formula,
+                                             length(coef(model$mr)),width)
+    }
+    models <- list(g0model=formula,scalemodel=NULL,fullscalemodel=NULL)
 
+    # Name int.range is misleading because it is only a right-hand point 
+    # different from width;  this needs to be expanded to an interval in 
+    #the future
+    if(is.null(int.range)){
+      pdot.list <- pdot.dsr.integrate.logistic(width,width, model$mr$coef, 
+                     newdata,integral.numeric, FALSE, models,GAM, point=point)
+    }else{
+      pdot.list <- pdot.dsr.integrate.logistic(int.range,width, model$mr$coef, 
+                       newdata,integral.numeric, FALSE, models,GAM, point=point)
+    }
 
+    if(left !=0){
+      pdot.list$pdot <- pdot.list$pdot -
+                    pdot.dsr.integrate.logistic(left, width, model$mr$coef, 
+                                   newdata,integral.numeric, FALSE, models,GAM,
+                                   point=point)$pdot
+    }
+
+    fitted <- pdot.list$pdot
+    if(is.null(newdata)){
+       names(fitted) <- model$mr$data$object[model$mr$data$observer==1]
+    }else{
+       names(fitted) <- newdata$object[newdata$observer==1]
+    }
+
+    return(list(fitted=fitted))
+  }
 }
